stm32-metapac

Crates

git

Versions

stm32h563ri

Flavors

M3dear

Struct M3dear 

#[repr(transparent)]
pub struct M3dear(pub u32);
RAMCFG memory 3 ECC double error address register.

Tuple Fields

0: u32

Implementations



impl M3dear

pub const fn edea(&self) -> u32

ECC double error address When the ALE bit is set in the MxCR register, this field is updated with the address corresponding to the ECC double error.

pub const fn set_edea(&mut self, val: u32)

ECC double error address When the ALE bit is set in the MxCR register, this field is updated with the address corresponding to the ECC double error.